==> haskell-network-control-0.0.2-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-3DG85s61UYS8qdnKsZZIgJ
key:                  network-control-0.0.2-3DG85s61UYS8qdnKsZZIgJ
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  779bfc5459df882c93547464031c3919
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-3DG85s61UYS8qdnKsZZIgJ
depends:
    base-4.17.2.1 psqueues-0.2.8.2-8KxEajARxns9hLS8UXLDNZ
    unix-time-0.4.17-4FPV428wEkuLLlUeOpzcNL

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-control-0.0.2-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-G2n8xcd9xtmGRiy5vjkHGJ
key:                  network-control-0.0.2-G2n8xcd9xtmGRiy5vjkHGJ
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  bc852d26c153c371ec471e583aac3df3
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-G2n8xcd9xtmGRiy5vjkHGJ
depends:
    base-4.17.2.1 psqueues-0.2.8.2-GVlV8GmsRiMJvLi3NeYDJJ
    unix-time-0.4.17-9fHdL2ArMbrJICOAGxTsok

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
